@@ -13,17 +13,17 @@ from pbpstats.resources.enhanced_pbp.data_nba.turnover import DataTurnover
 from pbpstats.resources.enhanced_pbp.data_nba.violation import DataViolation
 
 __all__ = [
-    'DataEjection',
-    'DataEndOfPeriod',
-    'DataFieldGoal',
-    'DataFoul',
-    'DataFreeThrow',
-    'DataJumpBall',
-    'DataRebound',
-    'DataReplay',
-    'DataStartOfPeriod',
-    'DataSubstitution',
-    'DataTimeout',
-    'DataTurnover',
-    'DataViolation',
+    "DataEjection",
+    "DataEndOfPeriod",
+    "DataFieldGoal",
+    "DataFoul",
+    "DataFreeThrow",
+    "DataJumpBall",
+    "DataRebound",
+    "DataReplay",
+    "DataStartOfPeriod",
+    "DataSubstitution",
+    "DataTimeout",
+    "DataTurnover",
+    "DataViolation",
 ]
